==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface DockerBuildStrategyFluent<A extends io.fabric8.openshift.api.model.DockerBuildStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToBuildArgs(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToBuildArgs(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToBuildArgs(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromBuildArgs(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getBuildArgs();
  public io.fabric8.kubernetes.api.model.EnvVar getBuildArg(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstBuildArg();
  public io.fabric8.kubernetes.api.model.EnvVar getLastBuildArg();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingBuildArg(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingBuildArg(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withBuildArgs(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> buildArgs);
  public A withBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... buildArgs);
  public java.lang.Boolean hasBuildArgs();
  public java.lang.String getDockerfilePath();
  public A withDockerfilePath(java.lang.String dockerfilePath);
  public java.lang.Boolean hasDockerfilePath();
  
  /**
   * Method is deprecated. use withDockerfilePath instead.
   */
  @java.lang.Deprecated
  public A withNewDockerfilePath(java.lang.String arg0);
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getLastEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public java.lang.Boolean hasEnv();
  public java.lang.Boolean getForcePull();
  public A withForcePull(java.lang.Boolean forcePull);
  public java.lang.Boolean hasForcePull();
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFrom();
  public io.fabric8.kubernetes.api.model.ObjectReference buildFrom();
  public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from);
  public java.lang.Boolean hasFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> withNewFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editOrNewFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.String getImageOptimizationPolicy();
  public A withImageOptimizationPolicy(java.lang.String imageOptimizationPolicy);
  public java.lang.Boolean hasImageOptimizationPolicy();
  
  /**
   * Method is deprecated. use withImageOptimizationPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewImageOptimizationPolicy(java.lang.String arg0);
  public java.lang.Boolean getNoCache();
  public A withNoCache(java.lang.Boolean noCache);
  public java.lang.Boolean hasNoCache();
  
  /**
   * This method has been deprecated, please use method buildPullSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getPullSecret();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildPullSecret();
  public A withPullSecret(io.fabric8.kubernetes.api.model.LocalObjectReference pullSecret);
  public java.lang.Boolean hasPullSecret();
  public A withNewPullSecret(java.lang.String name);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecretLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecretLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface FromNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PullSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<N>>{
    public N and();
    public N endPullSecret();
    
  }
  
}

==> openshift-model-5.12.4-sources.jar: io/fabric8/openshift/api/model/DockerBuildStrategyFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.kubernetes.api.model.EnvVar;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface DockerBuildStrategyFluent<A extends io.fabric8.openshift.api.model.DockerBuildStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToBuildArgs(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToBuildArgs(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToBuildArgs(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromBuildArgs(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getBuildArgs();
  public io.fabric8.kubernetes.api.model.EnvVar getBuildArg(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstBuildArg();
  public io.fabric8.kubernetes.api.model.EnvVar getLastBuildArg();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingBuildArg(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingBuildArg(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withBuildArgs(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> buildArgs);
  public A withBuildArgs(io.fabric8.kubernetes.api.model.EnvVar... buildArgs);
  public java.lang.Boolean hasBuildArgs();
  public java.lang.String getDockerfilePath();
  public A withDockerfilePath(java.lang.String dockerfilePath);
  public java.lang.Boolean hasDockerfilePath();
  
  /**
   * Method is deprecated. use withDockerfilePath instead.
   */
  @java.lang.Deprecated
  public A withNewDockerfilePath(java.lang.String arg0);
  public A addToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A setToEnv(java.lang.Integer index,io.fabric8.kubernetes.api.model.EnvVar item);
  public A addToEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A addAllToEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public A removeFromEnv(io.fabric8.kubernetes.api.model.EnvVar... items);
  public A removeAllFromEnv(java.util.Collection<io.fabric8.kubernetes.api.model.EnvVar> items);
  public java.util.List<io.fabric8.kubernetes.api.model.EnvVar> getEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getEnv(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.EnvVar getFirstEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getLastEnv();
  public io.fabric8.kubernetes.api.model.EnvVar getMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public java.lang.Boolean hasMatchingEnv(java.util.function.Predicate<io.fabric8.kubernetes.api.model.EnvVar> predicate);
  public A withEnv(java.util.List<io.fabric8.kubernetes.api.model.EnvVar> env);
  public A withEnv(io.fabric8.kubernetes.api.model.EnvVar... env);
  public java.lang.Boolean hasEnv();
  public java.lang.Boolean getForcePull();
  public A withForcePull(java.lang.Boolean forcePull);
  public java.lang.Boolean hasForcePull();
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectReference getFrom();
  public io.fabric8.kubernetes.api.model.ObjectReference buildFrom();
  public A withFrom(io.fabric8.kubernetes.api.model.ObjectReference from);
  public java.lang.Boolean hasFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> withNewFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> withNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editOrNewFrom();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<A> editOrNewFromLike(io.fabric8.kubernetes.api.model.ObjectReference item);
  public java.lang.String getImageOptimizationPolicy();
  public A withImageOptimizationPolicy(java.lang.String imageOptimizationPolicy);
  public java.lang.Boolean hasImageOptimizationPolicy();
  
  /**
   * Method is deprecated. use withImageOptimizationPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewImageOptimizationPolicy(java.lang.String arg0);
  public java.lang.Boolean getNoCache();
  public A withNoCache(java.lang.Boolean noCache);
  public java.lang.Boolean hasNoCache();
  
  /**
   * This method has been deprecated, please use method buildPullSecret instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getPullSecret();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildPullSecret();
  public A withPullSecret(io.fabric8.kubernetes.api.model.LocalObjectReference pullSecret);
  public java.lang.Boolean hasPullSecret();
  public A withNewPullSecret(java.lang.String name);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> withNewPullSecretLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecret();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<A> editOrNewPullSecretLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public A addToVolumes(java.lang.Integer index,io.fabric8.openshift.api.model.BuildVolume item);
  public A setToVolumes(java.lang.Integer index,io.fabric8.openshift.api.model.BuildVolume item);
  public A addToVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A addAllToVolumes(java.util.Collection<io.fabric8.openshift.api.model.BuildVolume> items);
  public A removeFromVolumes(io.fabric8.openshift.api.model.BuildVolume... items);
  public A removeAllFromVolumes(java.util.Collection<io.fabric8.openshift.api.model.BuildVolume> items);
  public A removeMatchingFromVolumes(java.util.function.Predicate<io.fabric8.openshift.api.model.BuildVolumeBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVolumes instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.BuildVolume> getVolumes();
  public java.util.List<io.fabric8.openshift.api.model.BuildVolume> buildVolumes();
  public io.fabric8.openshift.api.model.BuildVolume buildVolume(java.lang.Integer index);
  public io.fabric8.openshift.api.model.BuildVolume buildFirstVolume();
  public io.fabric8.openshift.api.model.BuildVolume buildLastVolume();
  public io.fabric8.openshift.api.model.BuildVolume buildMatchingVolume(java.util.function.Predicate<io.fabric8.openshift.api.model.BuildVolumeBuilder> predicate);
  public java.lang.Boolean hasMatchingVolume(java.util.function.Predicate<io.fabric8.openshift.api.model.BuildVolumeBuilder> predicate);
  public A withVolumes(java.util.List<io.fabric8.openshift.api.model.BuildVolume> volumes);
  public A withVolumes(io.fabric8.openshift.api.model.BuildVolume... volumes);
  public java.lang.Boolean hasVolumes();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> addNewVolume();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> addNewVolumeLike(io.fabric8.openshift.api.model.BuildVolume item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> setNewVolumeLike(java.lang.Integer index,io.fabric8.openshift.api.model.BuildVolume item);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> editVolume(java.lang.Integer index);
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> editFirstVolume();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> editLastVolume();
  public io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<A> editMatchingVolume(java.util.function.Predicate<io.fabric8.openshift.api.model.BuildVolumeBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface FromNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.ObjectReferenceFluent<io.fabric8.openshift.api.model.DockerBuildStrategyFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface PullSecretNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.openshift.api.model.DockerBuildStrategyFluent.PullSecretNested<N>>{
    public N and();
    public N endPullSecret();
    
  }
  public interface VolumesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.BuildVolumeFluent<io.fabric8.openshift.api.model.DockerBuildStrategyFluent.VolumesNested<N>>{
    public N and();
    public N endVolume();
    
  }
  
}
